@@ -5,6 +5,7 @@ use blib;
 
 use CFITSIO qw( :constants );
 use PDL;
+use Carp;
 
 CFITSIO::PerlyUnpacking(0);
 
@@ -30,7 +31,8 @@ $fptr->get_num_rows($nrows,$status);
 # find out which column the Y event coordinates are stored in
 #
 $fptr->get_colnum(0,'Y',$ycol,$status);
-($status == COL_NOT_FOUND) and "$0: could not find TTYPE 'Y' in binary table";
+($status == COL_NOT_FOUND) and
+    die "$0: could not find TTYPE 'Y' in binary table";
 
 #
 # make piddle, read data
@@ -38,6 +40,7 @@ $fptr->get_colnum(0,'Y',$ycol,$status);
 $pdl = zeroes($nrows)->long;
 $fptr->read_col_lng($ycol,1,1,$nrows,0,${$pdl->get_dataref},$anynul,$status);
 	check_status($status);
+$pdl->upd_data;
 
 #
 # create Y position histogram, plot data
@@ -47,16 +50,12 @@ my $y = $hist->sequence + $pdl->min;
 line $y, $hist;
 
 sub check_status {
-	my $status = shift;
-	my $errtxt;
-	if ($status) {
-		CFITSIO::fits_get_errstatus($status,$errtxt);
-		print STDERR <<EOP;
-$0 - CFITSIO error detected (see below), aborting
+    my $status = shift;
+    my $errtxt;
+    if ($status) {
+      CFITSIO::fits_get_errstatus($status,$errtxt);
+	croak "$0: CFITSIO error, aborting...$errtxt";
+    }
 
-   $errtxt
-
-EOP
-		exit 1;
-	}
+    return 1;
 }
